// -*-c++-*-
//
// C++ Interface for module: DubApp
//
// Description: 
//
//
// Author: Eray (exa) Ozkural, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef DubApp_Interface
#define DubApp_Interface

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// include files for KDE
#include <kapplication.h>
#include <kmainwindow.h>
#include <kaccel.h>
#include <kaction.h>

// forward declaration of the Dub classes
class DubView;

// Application stuff
class DubApp : public KMainWindow
{
  Q_OBJECT

  friend class DubView;

 public:
  /** construtor of DubApp, calls all init functions to create the application.
   */
  DubApp(QWidget* parent, const char* name="Dub Playlist");
  ~DubApp();

  /** save general Options like all bar positions and status as well as the geometry and the recent file list to the configuration
   * file
   */
  void saveOptions();
  /** read general Options again and initialize all variables like the recent file list
   */
  void readOptions();
  /** initializes the KActions of the application */
  void initActions();
  /** sets up the statusbar for the main window by initialzing a statuslabel.
   */
  void initStatusBar();
  /** initializes the document object of the main window that is connected to the view in initView().
   * @see initView();
   */
  void initDocument();
  /** creates the centerwidget of the KTMainWindow instance and sets it as the view
   */
  void initView();
  /** queryClose is called by KTMainWindow on each closeEvent of a window. Against the
   * default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
   * be saved if Modified; on cancel the closeEvent is rejected.
   * @see KTMainWindow#queryClose
   * @see KTMainWindow#closeEvent
   */
  virtual bool queryClose();
  /** queryExit is called by KTMainWindow when the last window of the application is going to be closed during the closeEvent().
   * Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's
   * properties.
   * @see KTMainWindow#queryExit
   * @see KTMainWindow#closeEvent
   */
  virtual bool queryExit();
  /** saves the window properties for each open window during session end to the session config file, including saving the currently
   * opened file by a temporary filename provided by KApplication.
   * @see KTMainWindow#saveProperties
   */
  virtual void saveProperties(KConfig *_cfg);
  /** reads the session config file and restores the application's state including the last opened files and documents by reading the
   * temporary files saved by saveProperties()
   * @see KTMainWindow#readProperties
   */
  virtual void readProperties(KConfig *_cfg);

public slots:
  void slotFileClose();
  void slotFileQuit();
  /** changes the statusbar contents for the standard label permanently, used to indicate current actions.
   * @param text the text that is displayed in the statusbar
   */
  void slotStatusMsg(const QString &text);
  /** get a pointer to view object */
  DubView* getView() {
    return view;
  }

public:
  DubView *view;

private:
  KConfig *config;
  /** view is the main widget which represents your working area. The View
   * class should handle all events of the view widget.  It is kept empty so
   * you can create your view according to your application's needs by
   * changing the view class.
   */

  // KAction pointers to enable/disable actions
  //KAction* fileQuit;
  KAction* fileClose;

};

#endif
